Get help
========

If you need help with any aspect of Aesara, let us know! We would be happy to hear from you.

Bugs and feature requests
-------------------------

.. tip::
   Take a look at the :ref:`troubleshoot` section if you are encountering difficulties with Aesara.

Report bugs on GitHub on the Aesara `Issues page <https://github.com/aesara-devs/aesara/issues>`__. You can post feature requests on the `Discussions page <https://github.com/aesara-devs/aesara/discussions>`__.

Help using Aesara
-----------------

Don’t know how to do X with Aesara? Start a `discussion <https://github.com/aesara-devs/aesara/discussions>`__ on GitHub.

Community
---------

For real-time feedback or more general chat about Aesara, join the `Discord server <https://discord.gg/h3sjmPYuGJ>`__ or the `Gitter room <https://gitter.im/aesara-devs/aesara>`__ to connect with the Aesara community.
